@@ -1,4 +1,4 @@
-from typing import Callable, Optional, Sequence, TypeVar, Union
+from typing import Callable, List, Literal, Optional, Sequence, TypeVar, Union
 from pathlib import Path
 
 
@@ -63,6 +63,7 @@ def iterate_and_save_pandas(
     file_name: Union[str, Path],
     write_index: bool = True,
     columns: Optional[Sequence[str]] = None,
+    write_mode: Literal["w", "a"] = "w",
 ):
     """Apply arguments to a function that returns a DataFrame and save to a .csv file.
 
@@ -71,6 +72,7 @@ def iterate_and_save_pandas(
     :param file_name: Name of the file to write
     :param write_index: Write the pandas index to the csv file
     :param columns: which columns to write.  If this is set the index is not written
+    :param write_mode: set the initial write mode.  "a" to append, "w" to overwrite.  Useful for resuming downloading.
 
     Usage::
 
@@ -86,8 +88,7 @@ def iterate_and_save_pandas(
 
     """
     argument: T
-    write_mode = "w"
-    write_headers = True
+    write_headers = write_mode != "a"
     for argument in tqdm(list(arguments)):
         try:
             data = f(argument)
@@ -99,8 +100,11 @@ def iterate_and_save_pandas(
             tqdm.write(f"Exception getting {argument} {e}")
         else:
             if columns:
-                data = data.reset_index()[columns]
-                write_index = False
+                try:
+                    data = data.reset_index()[columns]
+                except Exception as e:
+                    tqdm.write(f"Exception getting columns for {argument} {e}")
+                    continue
             data.to_csv(
                 file_name,
                 mode=write_mode,
@@ -108,4 +112,38 @@ def iterate_and_save_pandas(
                 header=write_headers,
             )
             write_mode = "a"
-            write_headers = False
\ No newline at end of file
+            write_headers = False
+
+
+def iterate_and_save_pyarrow_dataset(
+    arguments: Sequence[T],
+    f: Callable[[T], pd.DataFrame],
+    root_path: Union[str, Path],
+    partition_cols: Optional[List[str]] = ["ticker"],
+):
+    """
+    Apply the arguments to a function a save to a pyarrow dataset.
+
+    Usage::
+    >>> # Read the dataset
+    >>> import pyarrow.parquet as pq
+    >>> import pyarrow.compute as pc
+    >>> table = pq.read_table(<root_path>)
+    >>> expr = pc.field("ticker") == "MSFT"
+    >>> msft_data = table.filter(expr).to_pandas()
+
+    """
+    import pyarrow as pa
+    import pyarrow.parquet as pq
+
+    for argument in tqdm(list(arguments)):
+        df = f(argument)
+        if df.empty:
+            continue
+        table = pa.Table.from_pandas(df)
+        pq.write_to_dataset(
+            table=table,
+            root_path=root_path,
+            partition_cols=partition_cols,
+            **{"allow_truncated_timestamps": True, "coerce_timestamps": "us"},
+        )
\ No newline at end of file
