@@ -28,7 +28,7 @@ try:
     import pandas as pd
 
     period_number = pd.api.types.CategoricalDtype(  # type: ignore
-        categories=[1, 2, 3, 4, 5, 6, 0], ordered=True
+        categories=[1, 2, 3, 4, 5, 6, 0, -1], ordered=True
     )  # So annual is last in sorting.  5 and 6 are first half and 3QCUM.
 except ImportError:
     "Can't find pandas, won't be able to use the functions that return DataFrames."
@@ -433,18 +433,29 @@ def standardized(
         return data
     data["fiscal_period"] = (
         data["fiscal_year"].astype(str) + "-" + data["fiscal_period"].astype(str)
-    )
+    ).astype("string")
     data = data.drop("fiscal_year", axis=1)
 
     if "calendar_period" in data.columns:
-        data.calendar_period = data.calendar_period.astype(period_number)  # type: ignore
+        data.calendar_period = data.calendar_period.astype(period_number)
 
     if "calendar_period" in data.columns:
-        data.calendar_period = data.calendar_period.astype(period_number)  # type: ignore
+        data.calendar_period = data.calendar_period.astype(period_number)
 
-    for date_column in ["date_reported", "period_end", "period_start"]:
+    for date_column in ["date_reported", "period_end", "period_start", "date_modified"]:
         if date_column in data.columns:
-            data[date_column] = pd.to_datetime(data[date_column], errors="coerce")  # type: ignore
+            data[date_column] = pd.to_datetime(data[date_column], errors="coerce")
+    for string_column in [
+        "ticker",
+        "metric",
+        "CIK",
+        "filing_type",
+        "filing_accession_number",
+        "trace_url",
+    ]:
+        if string_column in data.columns:
+            data[string_column] = data[string_column].astype("string")
+
     index_columns = [
         "ticker",
         "metric",
